[tor-commits] [translation/support-portal] https://gitweb.torproject.org/translation.git/commit/?h=support-portal

2019-12-15 Thread translation
commit e27eeccfc1d9b6f784b73c01c9828ee107ce06e1
Author: Translation commit bot 
Date:   Sun Dec 15 23:55:01 2019 +

https://gitweb.torproject.org/translation.git/commit/?h=support-portal
---
 contents+es.po | 7 +--
 1 file changed, 5 insertions(+), 2 deletions(-)

diff --git a/contents+es.po b/contents+es.po
index d917128e39..0e383c9540 100644
--- a/contents+es.po
+++ b/contents+es.po
@@ -1513,6 +1513,9 @@ msgid ""
 " a multiple of 200px x 100px to prevent fingerprinting the screen "
 "dimensions."
 msgstr ""
+"El Navegador Tor en su modo por defecto inicia con una ventana de contenido "
+"dimensionada a un múltiplo de 200px x 100px para prevenir la identificación 
"
+"unívoca de las dimensiones de la pantalla."
 
 #: https//support.torproject.org/tbb/maximized-torbrowser-window/
 #: (content/tbb/maximized-torbrowser-window/contents+en.lrquestion.description)
@@ -6703,8 +6706,8 @@ msgid ""
 "Compass is a web application to learn about currently running [Tor "
 "relays](#relay) in bulk."
 msgstr ""
-"Compass is a web application to learn about currently running [Tor 
relays](#relay) in bulk.\n"
-"Compass es una aplicación web para aprender sobre la ejecución actual de 
[relays de tor](#relay) a granel."
+"Compass es una aplicación web para aprender sobre la ejecución actual de "
+"[relays de tor](#relay) a granel."
 
 #: https//support.torproject.org/misc/glossary/
 #: (content/misc/glossary/contents+en.lrquestion.description)

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [chutney/master] python: Add __future__ imports for python 3 compatibility

2019-12-15 Thread teor
commit f9d27ae30ca72db6f77a454e0b1b5274d49a66a9
Author: teor 
Date:   Thu Dec 12 15:44:02 2019 +1000

python: Add __future__ imports for python 3 compatibility

Closes ticket 32731.
---
 lib/chutney/Debug.py  | 3 +++
 lib/chutney/Host.py   | 4 
 lib/chutney/Templating.py | 4 +++-
 lib/chutney/TorNet.py | 4 +++-
 lib/chutney/Traffic.py| 3 +++
 lib/chutney/Util.py   | 5 -
 lib/chutney/__init__.py   | 4 
 scripts/chutney_tests/__init__.py | 4 
 scripts/chutney_tests/verify.py   | 6 +-
 9 files changed, 33 insertions(+), 4 deletions(-)

diff --git a/lib/chutney/Debug.py b/lib/chutney/Debug.py
index 85c9eee..9d06521 100755
--- a/lib/chutney/Debug.py
+++ b/lib/chutney/Debug.py
@@ -7,7 +7,10 @@
 #  restrict, so long as you retain the above notice(s) and this license
 #  in all redistributed copies and derived works.  There is no warranty.
 
+# Future imports for Python 2.7, mandatory in 3.0
+from __future__ import division
 from __future__ import print_function
+from __future__ import unicode_literals
 
 import cgitb
 import os
diff --git a/lib/chutney/Host.py b/lib/chutney/Host.py
index 75573d6..274e843 100644
--- a/lib/chutney/Host.py
+++ b/lib/chutney/Host.py
@@ -1,3 +1,7 @@
+# Future imports for Python 2.7, mandatory in 3.0
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
 
 import socket
 import chutney.Util
diff --git a/lib/chutney/Templating.py b/lib/chutney/Templating.py
index 6560e25..2a658ab 100755
--- a/lib/chutney/Templating.py
+++ b/lib/chutney/Templating.py
@@ -76,8 +76,10 @@
 
 """
 
+# Future imports for Python 2.7, mandatory in 3.0
+from __future__ import division
 from __future__ import print_function
-from __future__ import with_statement
+from __future__ import unicode_literals
 
 import string
 import os
diff --git a/lib/chutney/TorNet.py b/lib/chutney/TorNet.py
index e9cf8f4..e47907c 100644
--- a/lib/chutney/TorNet.py
+++ b/lib/chutney/TorNet.py
@@ -7,8 +7,10 @@
 #  restrict, so long as you retain the above notice(s) and this license
 #  in all redistributed copies and derived works.  There is no warranty.
 
+# Future imports for Python 2.7, mandatory in 3.0
+from __future__ import division
 from __future__ import print_function
-from __future__ import with_statement
+from __future__ import unicode_literals
 
 import cgitb
 import os
diff --git a/lib/chutney/Traffic.py b/lib/chutney/Traffic.py
index 02cca91..9990dcd 100755
--- a/lib/chutney/Traffic.py
+++ b/lib/chutney/Traffic.py
@@ -20,7 +20,10 @@
 #
 # For example code, see main() below.
 
+# Future imports for Python 2.7, mandatory in 3.0
+from __future__ import division
 from __future__ import print_function
+from __future__ import unicode_literals
 
 import sys
 import socket
diff --git a/lib/chutney/Util.py b/lib/chutney/Util.py
index f8b838e..761636b 100644
--- a/lib/chutney/Util.py
+++ b/lib/chutney/Util.py
@@ -1,4 +1,7 @@
-
+# Future imports for Python 2.7, mandatory in 3.0
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
 
 def memoized(fn):
 """Decorator: memoize a function."""
diff --git a/lib/chutney/__init__.py b/lib/chutney/__init__.py
index e69de29..cd47ba0 100644
--- a/lib/chutney/__init__.py
+++ b/lib/chutney/__init__.py
@@ -0,0 +1,4 @@
+# Future imports for Python 2.7, mandatory in 3.0
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
diff --git a/scripts/chutney_tests/__init__.py 
b/scripts/chutney_tests/__init__.py
index e69de29..cd47ba0 100644
--- a/scripts/chutney_tests/__init__.py
+++ b/scripts/chutney_tests/__init__.py
@@ -0,0 +1,4 @@
+# Future imports for Python 2.7, mandatory in 3.0
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
diff --git a/scripts/chutney_tests/verify.py b/scripts/chutney_tests/verify.py
index e97ff52..a0f0c3e 100644
--- a/scripts/chutney_tests/verify.py
+++ b/scripts/chutney_tests/verify.py
@@ -1,7 +1,11 @@
+# Future imports for Python 2.7, mandatory in 3.0
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import time
 import chutney
 
-
 def run_test(network):
 wait_time = network._dfltEnv['bootstrap_time']
 start_time = time.time()



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [chutney/master] torrc: Allow the user to disable the tor Sandbox

2019-12-15 Thread teor
commit f21ca5534fbc0e2d128fd964b474c62e5442bfbc
Author: teor 
Date:   Wed Dec 11 14:11:38 2019 +1000

torrc: Allow the user to disable the tor Sandbox

* Set the default for Sandbox based on the platform:
  1 for Linux, 0 for everything else.
* Allow the user to override it with --sandbox or CHUTNEY_TOR_SANDBOX

This feature can be used when tor's sandbox doesn't work with the local
glibc version.

Closes ticket 32721.
---
 README   | 19 --
 lib/chutney/TorNet.py| 68 +++-
 tools/test-network.sh|  9 +++
 torrc_templates/common.i | 18 -
 4 files changed, 94 insertions(+), 20 deletions(-)

diff --git a/README b/README
index c828e1d..0475b2f 100644
--- a/README
+++ b/README
@@ -70,6 +70,10 @@ Address/DNS Options:
   # Use tor's compile-time default for ServerDNSResolvConfFile
   --dns-conf-default CHUTNEY_DNS_CONF=""
 
+Sandbox Options:
+
+  --sandbox  CHUTNEY_TOR_SANDBOX=N (0 or 1)
+
 Warning Options:
   --all-warnings CHUTNEY_WARNINGS_IGNORE_EXPECTED=false
  CHUTNEY_WARNINGS_SUMMARY=false
@@ -214,15 +218,26 @@ Using DNS:
provides a local resolv.conf file containing IPv4, IPv6, and "localhost".
Use --dns-conf resolv.conf (relative paths work).
 
+The tor sandbox:
+
+   Chutney can run with the tor seccomp sandbox enabled. But if tor's sandbox
+   is broken on your local version of glibc, you can set CHUTNEY_TOR_SANDBOX=0
+   to disable the sandbox. If CHUTNEY_TOR_SANDBOX is unset, Sandbox defaults
+   to 1 on Linux, and 0 on other platforms.
+
 The configuration files:
 
   networks/basic holds the configuration for the network you're configuring
   above.  It refers to some torrc template files in torrc_templates/.
 
+  Chutney uses a templating system to produce torrc files from the templates.
+  These torrc files can be modified using various chutney options.
+
 The working files:
 
-  chutney sticks its working files, including all data directories, log
-  files, etc, in ./net/.  Each tor instance gets a subdirectory of net/nodes.
+  chutney sticks its working files, including all generated torrc files,
+  data directories, log files, etc, in ./net/.  Each tor instance gets a
+  subdirectory of net/nodes.
 
   You can override the directory "./net" with the CHUTNEY_DATA_DIR
   environment variable.
diff --cc lib/chutney/TorNet.py
index 2b91dfb,e47907c..ea3b320
--- a/lib/chutney/TorNet.py
+++ b/lib/chutney/TorNet.py
@@@ -7,20 -7,21 +7,22 @@@
  #  restrict, so long as you retain the above notice(s) and this license
  #  in all redistributed copies and derived works.  There is no warranty.
  
+ # Future imports for Python 2.7, mandatory in 3.0
+ from __future__ import division
  from __future__ import print_function
- from __future__ import with_statement
+ from __future__ import unicode_literals
  
  import cgitb
 +import errno
 +import importlib
  import os
 +import platform
 +import re
  import signal
 +import shutil
  import subprocess
  import sys
 -import re
 -import errno
  import time
 -import shutil
 -import importlib
  
  from chutney.Debug import debug_flag, debug
  

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] Merge branch 'ticket32629_035' into ticket32629_040

2019-12-15 Thread teor
commit 349554f40d503a33f4b85c8481ca1434ac07acbf
Merge: 055f5d4d1 6558bb446
Author: teor 
Date:   Sun Dec 1 20:26:51 2019 +1000

Merge branch 'ticket32629_035' into ticket32629_040

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 2 files changed, 5 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] Merge branch 'maint-0.3.5' into maint-0.4.0

2019-12-15 Thread teor
commit 748117298341de8a279f4437b6d557f0d50edb63
Merge: b9504f788 1cd20ff84
Author: teor 
Date:   Mon Dec 16 08:16:04 2019 +1000

Merge branch 'maint-0.3.5' into maint-0.4.0

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] changes: file for 32629

2019-12-15 Thread teor
commit b84e7715daba5bdcb20fa3f1148d2c518ea5704c
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] Merge branch 'maint-0.4.2' into release-0.4.2

2019-12-15 Thread teor
commit d5702a6340104434fe1d82a340c74b2393a1f8aa
Merge: ee4375a98 bd11fb109
Author: teor 
Date:   Mon Dec 16 08:16:24 2019 +1000

Merge branch 'maint-0.4.2' into release-0.4.2

 .travis.yml | 9 +
 changes/ticket32629 | 4 
 2 files changed, 9 insertions(+), 4 deletions(-)

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] Merge branch 'maint-0.4.1' into maint-0.4.2

2019-12-15 Thread teor
commit bd11fb10962f5b6e7d51ff5a0e6263ad39d4d184
Merge: 933b0c1b1 ffccf6fc5
Author: teor 
Date:   Mon Dec 16 08:16:20 2019 +1000

Merge branch 'maint-0.4.1' into maint-0.4.2




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.1] Travis: Disable the macOS Rust job

2019-12-15 Thread teor
commit 6558bb4460f360ee16653d9430ee00e969f3adf7
Author: teor 
Date:   Sun Dec 1 20:25:00 2019 +1000

Travis: Disable the macOS Rust job

This time, we're disabling it because it's the lowest priority job.
(And also slow.)

Part of 32629.
---
 .travis.yml | 9 ++---
 1 file changed, 6 insertions(+), 3 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 21c86ad93..bdcd94f91 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -62,10 +62,13 @@ matrix:
 - env: DISTCHECK="yes" ASCIIDOC_OPTIONS="" SKIP_MAKE_CHECK="yes"
 ## We check disable module dirauth
 - env: MODULES_OPTIONS="--disable-module-dirauth"
+## macOS builds are very slow, and we have a limited number of
+## concurrent macOS jobs. We're not actively developing Rust, so it is
+## the lowest priority.
 ## We run rust on macOS, because we have seen macOS rust failures before
-- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
-  compiler: clang
-  os: osx
+#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
+#  compiler: clang
+#  os: osx
 ## We run chutney on macOS, because macOS Travis has IPv6
 - env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
   os: osx



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.1] Merge branch 'maint-0.2.9' into maint-0.3.5

2019-12-15 Thread teor
commit 1cd20ff848eab6ee7b441c5aab0578ab02a114bc
Merge: 05908d57f 7dd594609
Author: teor 
Date:   Mon Dec 16 08:15:55 2019 +1000

Merge branch 'maint-0.2.9' into maint-0.3.5




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.0] Merge branch 'maint-0.3.5' into maint-0.4.0

2019-12-15 Thread teor
commit 748117298341de8a279f4437b6d557f0d50edb63
Merge: b9504f788 1cd20ff84
Author: teor 
Date:   Mon Dec 16 08:16:04 2019 +1000

Merge branch 'maint-0.3.5' into maint-0.4.0

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] Merge branch 'ticket32629_040' into ticket32629_041

2019-12-15 Thread teor
commit a00b9e5a86dd763e8d21958dc9022472f40a18d8
Merge: 26071aa3b 349554f40
Author: teor 
Date:   Sun Dec 1 20:26:55 2019 +1000

Merge branch 'ticket32629_040' into ticket32629_041

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 2 files changed, 5 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] Merge branch 'ticket32629_041' into ticket32629_042

2019-12-15 Thread teor
commit 4a157c7569c6ad5e37747852a823369b48229ef7
Merge: eb8170408 a00b9e5a8
Author: teor 
Date:   Sun Dec 1 20:28:44 2019 +1000

Merge branch 'ticket32629_041' into ticket32629_042

Merge RUST_VERSION from maint-0.4.2 with disabling the macOS Rust
job from ticket32629_041.

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 2 files changed, 5 insertions(+), 7 deletions(-)

diff --cc .travis.yml
index 252da6877,c56ced37b..f386500b2
--- a/.travis.yml
+++ b/.travis.yml
@@@ -64,9 -62,11 +64,11 @@@ matrix
  - env: DISTCHECK="yes" ASCIIDOC_OPTIONS="" SKIP_MAKE_CHECK="yes"
  ## We check disable module dirauth
  - env: MODULES_OPTIONS="--disable-module-dirauth"
+ ## macOS builds are very slow, and we have a limited number of
+ ## concurrent macOS jobs. We're not actively developing Rust, so it is
+ ## the lowest priority.
  ## We run rust on macOS, because we have seen macOS rust failures before
- # Disabled due to slow Travis macOS builds, see #32177
 -#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
 +#- env: RUST_VERSION="nightly" RUST_OPTIONS="--enable-rust 
--enable-cargo-online-mode"
  #  compiler: clang
  #  os: osx
  ## We run chutney on macOS, because macOS Travis has IPv6



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.1] Merge branch 'maint-0.4.1' into release-0.4.1

2019-12-15 Thread teor
commit 7c2e1f6ddd116eefc9f65f0536a5f3b1f5735966
Merge: 9fc50f057 ffccf6fc5
Author: teor 
Date:   Mon Dec 16 08:16:16 2019 +1000

Merge branch 'maint-0.4.1' into release-0.4.1

 .travis.yml | 9 +
 changes/ticket32629 | 4 
 2 files changed, 9 insertions(+), 4 deletions(-)

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] changes: file for 32629

2019-12-15 Thread teor
commit f86d508d49dd36fede7091635044603741fdd353
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] Travis: Disable the macOS Rust job

2019-12-15 Thread teor
commit 6558bb4460f360ee16653d9430ee00e969f3adf7
Author: teor 
Date:   Sun Dec 1 20:25:00 2019 +1000

Travis: Disable the macOS Rust job

This time, we're disabling it because it's the lowest priority job.
(And also slow.)

Part of 32629.
---
 .travis.yml | 9 ++---
 1 file changed, 6 insertions(+), 3 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 21c86ad93..bdcd94f91 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -62,10 +62,13 @@ matrix:
 - env: DISTCHECK="yes" ASCIIDOC_OPTIONS="" SKIP_MAKE_CHECK="yes"
 ## We check disable module dirauth
 - env: MODULES_OPTIONS="--disable-module-dirauth"
+## macOS builds are very slow, and we have a limited number of
+## concurrent macOS jobs. We're not actively developing Rust, so it is
+## the lowest priority.
 ## We run rust on macOS, because we have seen macOS rust failures before
-- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
-  compiler: clang
-  os: osx
+#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
+#  compiler: clang
+#  os: osx
 ## We run chutney on macOS, because macOS Travis has IPv6
 - env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
   os: osx



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.0] Merge remote-tracking branch 'tor-github/pr/1576' into maint-0.3.5

2019-12-15 Thread teor
commit 05908d57f64a4365f6715f19aba51ccd5849e635
Merge: 0c4f0ec97 a277f2894
Author: teor 
Date:   Mon Dec 16 08:14:04 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1576' into maint-0.3.5

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] Merge branch 'maint-0.2.9' into maint-0.3.5

2019-12-15 Thread teor
commit 1cd20ff848eab6ee7b441c5aab0578ab02a114bc
Merge: 05908d57f 7dd594609
Author: teor 
Date:   Mon Dec 16 08:15:55 2019 +1000

Merge branch 'maint-0.2.9' into maint-0.3.5




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] Merge remote-tracking branch 'tor-github/pr/1577' into maint-0.4.2

2019-12-15 Thread teor
commit 933b0c1b1badc1f02ebf5ff29916e3b6987cd8c5
Merge: b7d18f861 f86d508d4
Author: teor 
Date:   Mon Dec 16 08:14:29 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1577' into maint-0.4.2

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] Merge branch 'ticket32629_029' into ticket32629_035

2019-12-15 Thread teor
commit f2f7491cd9ea8a8c39b576106b44488202aa3c63
Merge: 453e092e5 99b5f1b26
Author: teor 
Date:   Thu Nov 28 12:21:08 2019 +1000

Merge branch 'ticket32629_029' into ticket32629_035

Merge re-enable chutney from ticket32629_029 with
stem from maint-0.3.5.

 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 2 files changed, 2 insertions(+), 6 deletions(-)

diff --cc .travis.yml
index 35c3502e8,aad0c3c3e..21c86ad93
--- a/.travis.yml
+++ b/.travis.yml
@@@ -55,23 -44,9 +55,22 @@@ matrix
compiler: clang
  ## We include a single coverage build with the best options for coverage
  - env: COVERAGE_OPTIONS="--enable-coverage" HARDENING_OPTIONS=""
 +## We run rust on Linux, because it's faster than rust on macOS
 +## We check rust offline
 +- env: RUST_OPTIONS="--enable-rust" TOR_RUST_DEPENDENCIES=true
 +## We check asciidoc with distcheck, to make sure we remove doc products
 +- env: DISTCHECK="yes" ASCIIDOC_OPTIONS="" SKIP_MAKE_CHECK="yes"
 +## We check disable module dirauth
 +- env: MODULES_OPTIONS="--disable-module-dirauth"
 +## We run rust on macOS, because we have seen macOS rust failures before
 +- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
 +  compiler: clang
 +  os: osx
  ## We run chutney on macOS, because macOS Travis has IPv6
- # Disabled due to slow Travis macOS builds, see #32177
- #- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
- #  os: osx
+ - env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
+   os: osx
 +## We clone our stem repo and run `make test-stem`
 +- env: TEST_STEM="yes" SKIP_MAKE_CHECK="yes"
  
## Allow the build to report success (with non-required sub-builds
## continuing to run) if all required sub-builds have succeeded.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] Merge remote-tracking branch 'tor-github/pr/1576' into maint-0.3.5

2019-12-15 Thread teor
commit 05908d57f64a4365f6715f19aba51ccd5849e635
Merge: 0c4f0ec97 a277f2894
Author: teor 
Date:   Mon Dec 16 08:14:04 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1576' into maint-0.3.5

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] Merge branch 'maint-0.4.0' into maint-0.4.1

2019-12-15 Thread teor
commit ffccf6fc55f691e01ccd3e756486415cbc7ffe8a
Merge: 7174a80ed 748117298
Author: teor 
Date:   Mon Dec 16 08:16:12 2019 +1000

Merge branch 'maint-0.4.0' into maint-0.4.1

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.0] changes: file for 32629

2019-12-15 Thread teor
commit a277f28947900fc2018f634078bf59eae166c75a
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

2019-12-15 Thread teor
commit 7dd59460941c50242e740ff0cbd84b588d66e26e
Merge: b7b467d3a b84e7715d
Author: teor 
Date:   Mon Dec 16 08:13:38 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 6 insertions(+), 6 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.1] Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

2019-12-15 Thread teor
commit 7dd59460941c50242e740ff0cbd84b588d66e26e
Merge: b7b467d3a b84e7715d
Author: teor 
Date:   Mon Dec 16 08:13:38 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 6 insertions(+), 6 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] Revert "Travis: Disable the Rust macOS build"

2019-12-15 Thread teor
commit 453e092e521626420fb679ad99fade0dd1c9af88
Author: teor 
Date:   Thu Nov 28 12:11:37 2019 +1000

Revert "Travis: Disable the Rust macOS build"

This reverts commit 4c4a0d50ff4fd01862b78e8cbfaabfa9e4d4ae12.
---
 .travis.yml | 7 +++
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 7f0e78587..35c3502e8 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -63,10 +63,9 @@ matrix:
 ## We check disable module dirauth
 - env: MODULES_OPTIONS="--disable-module-dirauth"
 ## We run rust on macOS, because we have seen macOS rust failures before
-# Disabled due to slow Travis macOS builds, see #32177
-#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
-#  compiler: clang
-#  os: osx
+- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
+  compiler: clang
+  os: osx
 ## We run chutney on macOS, because macOS Travis has IPv6
 # Disabled due to slow Travis macOS builds, see #32177
 #- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.1] Merge branch 'maint-0.3.5' into maint-0.4.0

2019-12-15 Thread teor
commit 748117298341de8a279f4437b6d557f0d50edb63
Merge: b9504f788 1cd20ff84
Author: teor 
Date:   Mon Dec 16 08:16:04 2019 +1000

Merge branch 'maint-0.3.5' into maint-0.4.0

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.0] Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

2019-12-15 Thread teor
commit 7dd59460941c50242e740ff0cbd84b588d66e26e
Merge: b7b467d3a b84e7715d
Author: teor 
Date:   Mon Dec 16 08:13:38 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 6 insertions(+), 6 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.3.5] Travis: Disable the macOS Rust job

2019-12-15 Thread teor
commit 6558bb4460f360ee16653d9430ee00e969f3adf7
Author: teor 
Date:   Sun Dec 1 20:25:00 2019 +1000

Travis: Disable the macOS Rust job

This time, we're disabling it because it's the lowest priority job.
(And also slow.)

Part of 32629.
---
 .travis.yml | 9 ++---
 1 file changed, 6 insertions(+), 3 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 21c86ad93..bdcd94f91 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -62,10 +62,13 @@ matrix:
 - env: DISTCHECK="yes" ASCIIDOC_OPTIONS="" SKIP_MAKE_CHECK="yes"
 ## We check disable module dirauth
 - env: MODULES_OPTIONS="--disable-module-dirauth"
+## macOS builds are very slow, and we have a limited number of
+## concurrent macOS jobs. We're not actively developing Rust, so it is
+## the lowest priority.
 ## We run rust on macOS, because we have seen macOS rust failures before
-- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
-  compiler: clang
-  os: osx
+#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
+#  compiler: clang
+#  os: osx
 ## We run chutney on macOS, because macOS Travis has IPv6
 - env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
   os: osx



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.1] changes: file for 32629

2019-12-15 Thread teor
commit b84e7715daba5bdcb20fa3f1148d2c518ea5704c
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.1] Merge branch 'maint-0.4.0' into maint-0.4.1

2019-12-15 Thread teor
commit ffccf6fc55f691e01ccd3e756486415cbc7ffe8a
Merge: 7174a80ed 748117298
Author: teor 
Date:   Mon Dec 16 08:16:12 2019 +1000

Merge branch 'maint-0.4.0' into maint-0.4.1

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.0] Revert "Travis: Disable the Rust macOS build"

2019-12-15 Thread teor
commit 453e092e521626420fb679ad99fade0dd1c9af88
Author: teor 
Date:   Thu Nov 28 12:11:37 2019 +1000

Revert "Travis: Disable the Rust macOS build"

This reverts commit 4c4a0d50ff4fd01862b78e8cbfaabfa9e4d4ae12.
---
 .travis.yml | 7 +++
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 7f0e78587..35c3502e8 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -63,10 +63,9 @@ matrix:
 ## We check disable module dirauth
 - env: MODULES_OPTIONS="--disable-module-dirauth"
 ## We run rust on macOS, because we have seen macOS rust failures before
-# Disabled due to slow Travis macOS builds, see #32177
-#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
-#  compiler: clang
-#  os: osx
+- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
+  compiler: clang
+  os: osx
 ## We run chutney on macOS, because macOS Travis has IPv6
 # Disabled due to slow Travis macOS builds, see #32177
 #- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] changes: file for 32629

2019-12-15 Thread teor
commit a277f28947900fc2018f634078bf59eae166c75a
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.2] Revert "Travis: Disable all but one macOS build"

2019-12-15 Thread teor
commit 99b5f1b261a3b8535e8e9b8ca8ca23303c2aea2d
Author: teor 
Date:   Thu Nov 28 12:10:10 2019 +1000

Revert "Travis: Disable all but one macOS build"

This reverts commit 511aeba8eeb24a953228e00917f64703059a7673.
---
 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 2 files changed, 2 insertions(+), 6 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 4ea9400b8..aad0c3c3e 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -45,9 +45,8 @@ matrix:
 ## We include a single coverage build with the best options for coverage
 - env: COVERAGE_OPTIONS="--enable-coverage" HARDENING_OPTIONS=""
 ## We run chutney on macOS, because macOS Travis has IPv6
-# Disabled due to slow Travis macOS builds, see #32177
-#- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
-#  os: osx
+- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
+  os: osx
 
   ## Allow the build to report success (with non-required sub-builds
   ## continuing to run) if all required sub-builds have succeeded.
diff --git a/changes/ticket32177 b/changes/ticket32177
deleted file mode 100644
index 6d6816acd..0
--- a/changes/ticket32177
+++ /dev/null
@@ -1,3 +0,0 @@
-  o Testing:
-- Disable all but one Travis CI macOS build, to mitigate slow scheduling
-  of Travis macOS jobs. Closes ticket 32177.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.1] Revert "Travis: Disable the Rust macOS build"

2019-12-15 Thread teor
commit 453e092e521626420fb679ad99fade0dd1c9af88
Author: teor 
Date:   Thu Nov 28 12:11:37 2019 +1000

Revert "Travis: Disable the Rust macOS build"

This reverts commit 4c4a0d50ff4fd01862b78e8cbfaabfa9e4d4ae12.
---
 .travis.yml | 7 +++
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 7f0e78587..35c3502e8 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -63,10 +63,9 @@ matrix:
 ## We check disable module dirauth
 - env: MODULES_OPTIONS="--disable-module-dirauth"
 ## We run rust on macOS, because we have seen macOS rust failures before
-# Disabled due to slow Travis macOS builds, see #32177
-#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
-#  compiler: clang
-#  os: osx
+- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
+  compiler: clang
+  os: osx
 ## We run chutney on macOS, because macOS Travis has IPv6
 # Disabled due to slow Travis macOS builds, see #32177
 #- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.1] Merge remote-tracking branch 'tor-github/pr/1576' into maint-0.3.5

2019-12-15 Thread teor
commit 05908d57f64a4365f6715f19aba51ccd5849e635
Merge: 0c4f0ec97 a277f2894
Author: teor 
Date:   Mon Dec 16 08:14:04 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1576' into maint-0.3.5

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.1] changes: file for 32629

2019-12-15 Thread teor
commit a277f28947900fc2018f634078bf59eae166c75a
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.1] Merge branch 'ticket32629_029' into ticket32629_035

2019-12-15 Thread teor
commit f2f7491cd9ea8a8c39b576106b44488202aa3c63
Merge: 453e092e5 99b5f1b26
Author: teor 
Date:   Thu Nov 28 12:21:08 2019 +1000

Merge branch 'ticket32629_029' into ticket32629_035

Merge re-enable chutney from ticket32629_029 with
stem from maint-0.3.5.

 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 2 files changed, 2 insertions(+), 6 deletions(-)

diff --cc .travis.yml
index 35c3502e8,aad0c3c3e..21c86ad93
--- a/.travis.yml
+++ b/.travis.yml
@@@ -55,23 -44,9 +55,22 @@@ matrix
compiler: clang
  ## We include a single coverage build with the best options for coverage
  - env: COVERAGE_OPTIONS="--enable-coverage" HARDENING_OPTIONS=""
 +## We run rust on Linux, because it's faster than rust on macOS
 +## We check rust offline
 +- env: RUST_OPTIONS="--enable-rust" TOR_RUST_DEPENDENCIES=true
 +## We check asciidoc with distcheck, to make sure we remove doc products
 +- env: DISTCHECK="yes" ASCIIDOC_OPTIONS="" SKIP_MAKE_CHECK="yes"
 +## We check disable module dirauth
 +- env: MODULES_OPTIONS="--disable-module-dirauth"
 +## We run rust on macOS, because we have seen macOS rust failures before
 +- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
 +  compiler: clang
 +  os: osx
  ## We run chutney on macOS, because macOS Travis has IPv6
- # Disabled due to slow Travis macOS builds, see #32177
- #- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
- #  os: osx
+ - env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
+   os: osx
 +## We clone our stem repo and run `make test-stem`
 +- env: TEST_STEM="yes" SKIP_MAKE_CHECK="yes"
  
## Allow the build to report success (with non-required sub-builds
## continuing to run) if all required sub-builds have succeeded.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.1] Revert "Travis: Disable all but one macOS build"

2019-12-15 Thread teor
commit 99b5f1b261a3b8535e8e9b8ca8ca23303c2aea2d
Author: teor 
Date:   Thu Nov 28 12:10:10 2019 +1000

Revert "Travis: Disable all but one macOS build"

This reverts commit 511aeba8eeb24a953228e00917f64703059a7673.
---
 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 2 files changed, 2 insertions(+), 6 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 4ea9400b8..aad0c3c3e 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -45,9 +45,8 @@ matrix:
 ## We include a single coverage build with the best options for coverage
 - env: COVERAGE_OPTIONS="--enable-coverage" HARDENING_OPTIONS=""
 ## We run chutney on macOS, because macOS Travis has IPv6
-# Disabled due to slow Travis macOS builds, see #32177
-#- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
-#  os: osx
+- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
+  os: osx
 
   ## Allow the build to report success (with non-required sub-builds
   ## continuing to run) if all required sub-builds have succeeded.
diff --git a/changes/ticket32177 b/changes/ticket32177
deleted file mode 100644
index 6d6816acd..0
--- a/changes/ticket32177
+++ /dev/null
@@ -1,3 +0,0 @@
-  o Testing:
-- Disable all but one Travis CI macOS build, to mitigate slow scheduling
-  of Travis macOS jobs. Closes ticket 32177.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.0] Merge branch 'maint-0.4.0' into release-0.4.0

2019-12-15 Thread teor
commit c4eb6740f9e36fca9f2fdd4ea1620047ad67b045
Merge: 793c4a3c9 748117298
Author: teor 
Date:   Mon Dec 16 08:16:08 2019 +1000

Merge branch 'maint-0.4.0' into release-0.4.0

 .travis.yml | 9 +
 changes/ticket32629 | 4 
 2 files changed, 9 insertions(+), 4 deletions(-)

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.3.5] Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

2019-12-15 Thread teor
commit 7dd59460941c50242e740ff0cbd84b588d66e26e
Merge: b7b467d3a b84e7715d
Author: teor 
Date:   Mon Dec 16 08:13:38 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 6 insertions(+), 6 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.0] Merge branch 'maint-0.2.9' into maint-0.3.5

2019-12-15 Thread teor
commit 1cd20ff848eab6ee7b441c5aab0578ab02a114bc
Merge: 05908d57f 7dd594609
Author: teor 
Date:   Mon Dec 16 08:15:55 2019 +1000

Merge branch 'maint-0.2.9' into maint-0.3.5




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.0] changes: file for 32629

2019-12-15 Thread teor
commit b84e7715daba5bdcb20fa3f1148d2c518ea5704c
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.0] Travis: Disable the macOS Rust job

2019-12-15 Thread teor
commit 6558bb4460f360ee16653d9430ee00e969f3adf7
Author: teor 
Date:   Sun Dec 1 20:25:00 2019 +1000

Travis: Disable the macOS Rust job

This time, we're disabling it because it's the lowest priority job.
(And also slow.)

Part of 32629.
---
 .travis.yml | 9 ++---
 1 file changed, 6 insertions(+), 3 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 21c86ad93..bdcd94f91 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -62,10 +62,13 @@ matrix:
 - env: DISTCHECK="yes" ASCIIDOC_OPTIONS="" SKIP_MAKE_CHECK="yes"
 ## We check disable module dirauth
 - env: MODULES_OPTIONS="--disable-module-dirauth"
+## macOS builds are very slow, and we have a limited number of
+## concurrent macOS jobs. We're not actively developing Rust, so it is
+## the lowest priority.
 ## We run rust on macOS, because we have seen macOS rust failures before
-- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
-  compiler: clang
-  os: osx
+#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
+#  compiler: clang
+#  os: osx
 ## We run chutney on macOS, because macOS Travis has IPv6
 - env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
   os: osx



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.0] Merge branch 'ticket32629_029' into ticket32629_035

2019-12-15 Thread teor
commit f2f7491cd9ea8a8c39b576106b44488202aa3c63
Merge: 453e092e5 99b5f1b26
Author: teor 
Date:   Thu Nov 28 12:21:08 2019 +1000

Merge branch 'ticket32629_029' into ticket32629_035

Merge re-enable chutney from ticket32629_029 with
stem from maint-0.3.5.

 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 2 files changed, 2 insertions(+), 6 deletions(-)

diff --cc .travis.yml
index 35c3502e8,aad0c3c3e..21c86ad93
--- a/.travis.yml
+++ b/.travis.yml
@@@ -55,23 -44,9 +55,22 @@@ matrix
compiler: clang
  ## We include a single coverage build with the best options for coverage
  - env: COVERAGE_OPTIONS="--enable-coverage" HARDENING_OPTIONS=""
 +## We run rust on Linux, because it's faster than rust on macOS
 +## We check rust offline
 +- env: RUST_OPTIONS="--enable-rust" TOR_RUST_DEPENDENCIES=true
 +## We check asciidoc with distcheck, to make sure we remove doc products
 +- env: DISTCHECK="yes" ASCIIDOC_OPTIONS="" SKIP_MAKE_CHECK="yes"
 +## We check disable module dirauth
 +- env: MODULES_OPTIONS="--disable-module-dirauth"
 +## We run rust on macOS, because we have seen macOS rust failures before
 +- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
 +  compiler: clang
 +  os: osx
  ## We run chutney on macOS, because macOS Travis has IPv6
- # Disabled due to slow Travis macOS builds, see #32177
- #- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
- #  os: osx
+ - env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
+   os: osx
 +## We clone our stem repo and run `make test-stem`
 +- env: TEST_STEM="yes" SKIP_MAKE_CHECK="yes"
  
## Allow the build to report success (with non-required sub-builds
## continuing to run) if all required sub-builds have succeeded.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.4.0] Revert "Travis: Disable all but one macOS build"

2019-12-15 Thread teor
commit 99b5f1b261a3b8535e8e9b8ca8ca23303c2aea2d
Author: teor 
Date:   Thu Nov 28 12:10:10 2019 +1000

Revert "Travis: Disable all but one macOS build"

This reverts commit 511aeba8eeb24a953228e00917f64703059a7673.
---
 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 2 files changed, 2 insertions(+), 6 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 4ea9400b8..aad0c3c3e 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -45,9 +45,8 @@ matrix:
 ## We include a single coverage build with the best options for coverage
 - env: COVERAGE_OPTIONS="--enable-coverage" HARDENING_OPTIONS=""
 ## We run chutney on macOS, because macOS Travis has IPv6
-# Disabled due to slow Travis macOS builds, see #32177
-#- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
-#  os: osx
+- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
+  os: osx
 
   ## Allow the build to report success (with non-required sub-builds
   ## continuing to run) if all required sub-builds have succeeded.
diff --git a/changes/ticket32177 b/changes/ticket32177
deleted file mode 100644
index 6d6816acd..0
--- a/changes/ticket32177
+++ /dev/null
@@ -1,3 +0,0 @@
-  o Testing:
-- Disable all but one Travis CI macOS build, to mitigate slow scheduling
-  of Travis macOS jobs. Closes ticket 32177.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.3.5] changes: file for 32629

2019-12-15 Thread teor
commit a277f28947900fc2018f634078bf59eae166c75a
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.2.9] Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

2019-12-15 Thread teor
commit 7dd59460941c50242e740ff0cbd84b588d66e26e
Merge: b7b467d3a b84e7715d
Author: teor 
Date:   Mon Dec 16 08:13:38 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 6 insertions(+), 6 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.3.5] Merge branch 'maint-0.2.9' into maint-0.3.5

2019-12-15 Thread teor
commit 1cd20ff848eab6ee7b441c5aab0578ab02a114bc
Merge: 05908d57f 7dd594609
Author: teor 
Date:   Mon Dec 16 08:15:55 2019 +1000

Merge branch 'maint-0.2.9' into maint-0.3.5




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.2.9] Revert "Travis: Disable all but one macOS build"

2019-12-15 Thread teor
commit 99b5f1b261a3b8535e8e9b8ca8ca23303c2aea2d
Author: teor 
Date:   Thu Nov 28 12:10:10 2019 +1000

Revert "Travis: Disable all but one macOS build"

This reverts commit 511aeba8eeb24a953228e00917f64703059a7673.
---
 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 2 files changed, 2 insertions(+), 6 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 4ea9400b8..aad0c3c3e 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -45,9 +45,8 @@ matrix:
 ## We include a single coverage build with the best options for coverage
 - env: COVERAGE_OPTIONS="--enable-coverage" HARDENING_OPTIONS=""
 ## We run chutney on macOS, because macOS Travis has IPv6
-# Disabled due to slow Travis macOS builds, see #32177
-#- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
-#  os: osx
+- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
+  os: osx
 
   ## Allow the build to report success (with non-required sub-builds
   ## continuing to run) if all required sub-builds have succeeded.
diff --git a/changes/ticket32177 b/changes/ticket32177
deleted file mode 100644
index 6d6816acd..0
--- a/changes/ticket32177
+++ /dev/null
@@ -1,3 +0,0 @@
-  o Testing:
-- Disable all but one Travis CI macOS build, to mitigate slow scheduling
-  of Travis macOS jobs. Closes ticket 32177.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.3.5] Merge branch 'maint-0.3.5' into release-0.3.5

2019-12-15 Thread teor
commit 28e708fcbc80d181367bc76553eb6a4325372bb7
Merge: 09a3bd1ff 1cd20ff84
Author: teor 
Date:   Mon Dec 16 08:16:00 2019 +1000

Merge branch 'maint-0.3.5' into release-0.3.5

 .travis.yml | 9 +
 changes/ticket32629 | 4 
 2 files changed, 9 insertions(+), 4 deletions(-)

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.3.5] Revert "Travis: Disable the Rust macOS build"

2019-12-15 Thread teor
commit 453e092e521626420fb679ad99fade0dd1c9af88
Author: teor 
Date:   Thu Nov 28 12:11:37 2019 +1000

Revert "Travis: Disable the Rust macOS build"

This reverts commit 4c4a0d50ff4fd01862b78e8cbfaabfa9e4d4ae12.
---
 .travis.yml | 7 +++
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 7f0e78587..35c3502e8 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -63,10 +63,9 @@ matrix:
 ## We check disable module dirauth
 - env: MODULES_OPTIONS="--disable-module-dirauth"
 ## We run rust on macOS, because we have seen macOS rust failures before
-# Disabled due to slow Travis macOS builds, see #32177
-#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
-#  compiler: clang
-#  os: osx
+- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
+  compiler: clang
+  os: osx
 ## We run chutney on macOS, because macOS Travis has IPv6
 # Disabled due to slow Travis macOS builds, see #32177
 #- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.3.5] Merge remote-tracking branch 'tor-github/pr/1576' into maint-0.3.5

2019-12-15 Thread teor
commit 05908d57f64a4365f6715f19aba51ccd5849e635
Merge: 0c4f0ec97 a277f2894
Author: teor 
Date:   Mon Dec 16 08:14:04 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1576' into maint-0.3.5

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.3.5] Merge branch 'ticket32629_029' into ticket32629_035

2019-12-15 Thread teor
commit f2f7491cd9ea8a8c39b576106b44488202aa3c63
Merge: 453e092e5 99b5f1b26
Author: teor 
Date:   Thu Nov 28 12:21:08 2019 +1000

Merge branch 'ticket32629_029' into ticket32629_035

Merge re-enable chutney from ticket32629_029 with
stem from maint-0.3.5.

 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 2 files changed, 2 insertions(+), 6 deletions(-)

diff --cc .travis.yml
index 35c3502e8,aad0c3c3e..21c86ad93
--- a/.travis.yml
+++ b/.travis.yml
@@@ -55,23 -44,9 +55,22 @@@ matrix
compiler: clang
  ## We include a single coverage build with the best options for coverage
  - env: COVERAGE_OPTIONS="--enable-coverage" HARDENING_OPTIONS=""
 +## We run rust on Linux, because it's faster than rust on macOS
 +## We check rust offline
 +- env: RUST_OPTIONS="--enable-rust" TOR_RUST_DEPENDENCIES=true
 +## We check asciidoc with distcheck, to make sure we remove doc products
 +- env: DISTCHECK="yes" ASCIIDOC_OPTIONS="" SKIP_MAKE_CHECK="yes"
 +## We check disable module dirauth
 +- env: MODULES_OPTIONS="--disable-module-dirauth"
 +## We run rust on macOS, because we have seen macOS rust failures before
 +- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
 +  compiler: clang
 +  os: osx
  ## We run chutney on macOS, because macOS Travis has IPv6
- # Disabled due to slow Travis macOS builds, see #32177
- #- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
- #  os: osx
+ - env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
+   os: osx
 +## We clone our stem repo and run `make test-stem`
 +- env: TEST_STEM="yes" SKIP_MAKE_CHECK="yes"
  
## Allow the build to report success (with non-required sub-builds
## continuing to run) if all required sub-builds have succeeded.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.3.5] changes: file for 32629

2019-12-15 Thread teor
commit b84e7715daba5bdcb20fa3f1148d2c518ea5704c
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.3.5] Revert "Travis: Disable all but one macOS build"

2019-12-15 Thread teor
commit 99b5f1b261a3b8535e8e9b8ca8ca23303c2aea2d
Author: teor 
Date:   Thu Nov 28 12:10:10 2019 +1000

Revert "Travis: Disable all but one macOS build"

This reverts commit 511aeba8eeb24a953228e00917f64703059a7673.
---
 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 2 files changed, 2 insertions(+), 6 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 4ea9400b8..aad0c3c3e 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -45,9 +45,8 @@ matrix:
 ## We include a single coverage build with the best options for coverage
 - env: COVERAGE_OPTIONS="--enable-coverage" HARDENING_OPTIONS=""
 ## We run chutney on macOS, because macOS Travis has IPv6
-# Disabled due to slow Travis macOS builds, see #32177
-#- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
-#  os: osx
+- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
+  os: osx
 
   ## Allow the build to report success (with non-required sub-builds
   ## continuing to run) if all required sub-builds have succeeded.
diff --git a/changes/ticket32177 b/changes/ticket32177
deleted file mode 100644
index 6d6816acd..0
--- a/changes/ticket32177
+++ /dev/null
@@ -1,3 +0,0 @@
-  o Testing:
-- Disable all but one Travis CI macOS build, to mitigate slow scheduling
-  of Travis macOS jobs. Closes ticket 32177.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] Merge branch 'maint-0.4.0' into maint-0.4.1

2019-12-15 Thread teor
commit ffccf6fc55f691e01ccd3e756486415cbc7ffe8a
Merge: 7174a80ed 748117298
Author: teor 
Date:   Mon Dec 16 08:16:12 2019 +1000

Merge branch 'maint-0.4.0' into maint-0.4.1

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] Merge branch 'maint-0.3.5' into maint-0.4.0

2019-12-15 Thread teor
commit 748117298341de8a279f4437b6d557f0d50edb63
Merge: b9504f788 1cd20ff84
Author: teor 
Date:   Mon Dec 16 08:16:04 2019 +1000

Merge branch 'maint-0.3.5' into maint-0.4.0

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] changes: file for 32629

2019-12-15 Thread teor
commit f86d508d49dd36fede7091635044603741fdd353
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.2.9] Merge branch 'maint-0.2.9' into release-0.2.9

2019-12-15 Thread teor
commit 95caab8cc6962066a20390282afdd70ba6e6ec2b
Merge: e49ec773d 7dd594609
Author: teor 
Date:   Mon Dec 16 08:15:46 2019 +1000

Merge branch 'maint-0.2.9' into release-0.2.9

 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 6 insertions(+), 6 deletions(-)

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] Merge branch 'ticket32629_041' into ticket32629_042

2019-12-15 Thread teor
commit 4a157c7569c6ad5e37747852a823369b48229ef7
Merge: eb8170408 a00b9e5a8
Author: teor 
Date:   Sun Dec 1 20:28:44 2019 +1000

Merge branch 'ticket32629_041' into ticket32629_042

Merge RUST_VERSION from maint-0.4.2 with disabling the macOS Rust
job from ticket32629_041.

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 2 files changed, 5 insertions(+), 7 deletions(-)

diff --cc .travis.yml
index 252da6877,c56ced37b..f386500b2
--- a/.travis.yml
+++ b/.travis.yml
@@@ -64,9 -62,11 +64,11 @@@ matrix
  - env: DISTCHECK="yes" ASCIIDOC_OPTIONS="" SKIP_MAKE_CHECK="yes"
  ## We check disable module dirauth
  - env: MODULES_OPTIONS="--disable-module-dirauth"
+ ## macOS builds are very slow, and we have a limited number of
+ ## concurrent macOS jobs. We're not actively developing Rust, so it is
+ ## the lowest priority.
  ## We run rust on macOS, because we have seen macOS rust failures before
- # Disabled due to slow Travis macOS builds, see #32177
 -#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
 +#- env: RUST_VERSION="nightly" RUST_OPTIONS="--enable-rust 
--enable-cargo-online-mode"
  #  compiler: clang
  #  os: osx
  ## We run chutney on macOS, because macOS Travis has IPv6



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/release-0.2.9] changes: file for 32629

2019-12-15 Thread teor
commit b84e7715daba5bdcb20fa3f1148d2c518ea5704c
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] Merge branch 'maint-0.4.1' into maint-0.4.2

2019-12-15 Thread teor
commit bd11fb10962f5b6e7d51ff5a0e6263ad39d4d184
Merge: 933b0c1b1 ffccf6fc5
Author: teor 
Date:   Mon Dec 16 08:16:20 2019 +1000

Merge branch 'maint-0.4.1' into maint-0.4.2

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] Merge remote-tracking branch 'tor-github/pr/1576' into maint-0.3.5

2019-12-15 Thread teor
commit 05908d57f64a4365f6715f19aba51ccd5849e635
Merge: 0c4f0ec97 a277f2894
Author: teor 
Date:   Mon Dec 16 08:14:04 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1576' into maint-0.3.5

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] Merge branch 'maint-0.2.9' into maint-0.3.5

2019-12-15 Thread teor
commit 1cd20ff848eab6ee7b441c5aab0578ab02a114bc
Merge: 05908d57f 7dd594609
Author: teor 
Date:   Mon Dec 16 08:15:55 2019 +1000

Merge branch 'maint-0.2.9' into maint-0.3.5




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] changes: file for 32629

2019-12-15 Thread teor
commit a277f28947900fc2018f634078bf59eae166c75a
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] changes: file for 32629

2019-12-15 Thread teor
commit b84e7715daba5bdcb20fa3f1148d2c518ea5704c
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] Merge branch 'ticket32629_029' into ticket32629_035

2019-12-15 Thread teor
commit f2f7491cd9ea8a8c39b576106b44488202aa3c63
Merge: 453e092e5 99b5f1b26
Author: teor 
Date:   Thu Nov 28 12:21:08 2019 +1000

Merge branch 'ticket32629_029' into ticket32629_035

Merge re-enable chutney from ticket32629_029 with
stem from maint-0.3.5.

 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 2 files changed, 2 insertions(+), 6 deletions(-)

diff --cc .travis.yml
index 35c3502e8,aad0c3c3e..21c86ad93
--- a/.travis.yml
+++ b/.travis.yml
@@@ -55,23 -44,9 +55,22 @@@ matrix
compiler: clang
  ## We include a single coverage build with the best options for coverage
  - env: COVERAGE_OPTIONS="--enable-coverage" HARDENING_OPTIONS=""
 +## We run rust on Linux, because it's faster than rust on macOS
 +## We check rust offline
 +- env: RUST_OPTIONS="--enable-rust" TOR_RUST_DEPENDENCIES=true
 +## We check asciidoc with distcheck, to make sure we remove doc products
 +- env: DISTCHECK="yes" ASCIIDOC_OPTIONS="" SKIP_MAKE_CHECK="yes"
 +## We check disable module dirauth
 +- env: MODULES_OPTIONS="--disable-module-dirauth"
 +## We run rust on macOS, because we have seen macOS rust failures before
 +- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
 +  compiler: clang
 +  os: osx
  ## We run chutney on macOS, because macOS Travis has IPv6
- # Disabled due to slow Travis macOS builds, see #32177
- #- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
- #  os: osx
+ - env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
+   os: osx
 +## We clone our stem repo and run `make test-stem`
 +- env: TEST_STEM="yes" SKIP_MAKE_CHECK="yes"
  
## Allow the build to report success (with non-required sub-builds
## continuing to run) if all required sub-builds have succeeded.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] Revert "Travis: Disable all but one macOS build"

2019-12-15 Thread teor
commit 99b5f1b261a3b8535e8e9b8ca8ca23303c2aea2d
Author: teor 
Date:   Thu Nov 28 12:10:10 2019 +1000

Revert "Travis: Disable all but one macOS build"

This reverts commit 511aeba8eeb24a953228e00917f64703059a7673.
---
 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 2 files changed, 2 insertions(+), 6 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 4ea9400b8..aad0c3c3e 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -45,9 +45,8 @@ matrix:
 ## We include a single coverage build with the best options for coverage
 - env: COVERAGE_OPTIONS="--enable-coverage" HARDENING_OPTIONS=""
 ## We run chutney on macOS, because macOS Travis has IPv6
-# Disabled due to slow Travis macOS builds, see #32177
-#- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
-#  os: osx
+- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
+  os: osx
 
   ## Allow the build to report success (with non-required sub-builds
   ## continuing to run) if all required sub-builds have succeeded.
diff --git a/changes/ticket32177 b/changes/ticket32177
deleted file mode 100644
index 6d6816acd..0
--- a/changes/ticket32177
+++ /dev/null
@@ -1,3 +0,0 @@
-  o Testing:
-- Disable all but one Travis CI macOS build, to mitigate slow scheduling
-  of Travis macOS jobs. Closes ticket 32177.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] Revert "Travis: Disable the Rust macOS build"

2019-12-15 Thread teor
commit 453e092e521626420fb679ad99fade0dd1c9af88
Author: teor 
Date:   Thu Nov 28 12:11:37 2019 +1000

Revert "Travis: Disable the Rust macOS build"

This reverts commit 4c4a0d50ff4fd01862b78e8cbfaabfa9e4d4ae12.
---
 .travis.yml | 7 +++
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 7f0e78587..35c3502e8 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -63,10 +63,9 @@ matrix:
 ## We check disable module dirauth
 - env: MODULES_OPTIONS="--disable-module-dirauth"
 ## We run rust on macOS, because we have seen macOS rust failures before
-# Disabled due to slow Travis macOS builds, see #32177
-#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
-#  compiler: clang
-#  os: osx
+- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
+  compiler: clang
+  os: osx
 ## We run chutney on macOS, because macOS Travis has IPv6
 # Disabled due to slow Travis macOS builds, see #32177
 #- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] Travis: Disable the macOS Rust job

2019-12-15 Thread teor
commit 6558bb4460f360ee16653d9430ee00e969f3adf7
Author: teor 
Date:   Sun Dec 1 20:25:00 2019 +1000

Travis: Disable the macOS Rust job

This time, we're disabling it because it's the lowest priority job.
(And also slow.)

Part of 32629.
---
 .travis.yml | 9 ++---
 1 file changed, 6 insertions(+), 3 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 21c86ad93..bdcd94f91 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -62,10 +62,13 @@ matrix:
 - env: DISTCHECK="yes" ASCIIDOC_OPTIONS="" SKIP_MAKE_CHECK="yes"
 ## We check disable module dirauth
 - env: MODULES_OPTIONS="--disable-module-dirauth"
+## macOS builds are very slow, and we have a limited number of
+## concurrent macOS jobs. We're not actively developing Rust, so it is
+## the lowest priority.
 ## We run rust on macOS, because we have seen macOS rust failures before
-- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
-  compiler: clang
-  os: osx
+#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
+#  compiler: clang
+#  os: osx
 ## We run chutney on macOS, because macOS Travis has IPv6
 - env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
   os: osx



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] Merge remote-tracking branch 'tor-github/pr/1577' into maint-0.4.2

2019-12-15 Thread teor
commit 933b0c1b1badc1f02ebf5ff29916e3b6987cd8c5
Merge: b7d18f861 f86d508d4
Author: teor 
Date:   Mon Dec 16 08:14:29 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1577' into maint-0.4.2

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] Merge branch 'ticket32629_035' into ticket32629_040

2019-12-15 Thread teor
commit 349554f40d503a33f4b85c8481ca1434ac07acbf
Merge: 055f5d4d1 6558bb446
Author: teor 
Date:   Sun Dec 1 20:26:51 2019 +1000

Merge branch 'ticket32629_035' into ticket32629_040

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 2 files changed, 5 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

2019-12-15 Thread teor
commit 7dd59460941c50242e740ff0cbd84b588d66e26e
Merge: b7b467d3a b84e7715d
Author: teor 
Date:   Mon Dec 16 08:13:38 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 6 insertions(+), 6 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.2] Merge branch 'ticket32629_040' into ticket32629_041

2019-12-15 Thread teor
commit a00b9e5a86dd763e8d21958dc9022472f40a18d8
Merge: 26071aa3b 349554f40
Author: teor 
Date:   Sun Dec 1 20:26:55 2019 +1000

Merge branch 'ticket32629_040' into ticket32629_041

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 2 files changed, 5 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.1] Merge branch 'ticket32629_029' into ticket32629_035

2019-12-15 Thread teor
commit f2f7491cd9ea8a8c39b576106b44488202aa3c63
Merge: 453e092e5 99b5f1b26
Author: teor 
Date:   Thu Nov 28 12:21:08 2019 +1000

Merge branch 'ticket32629_029' into ticket32629_035

Merge re-enable chutney from ticket32629_029 with
stem from maint-0.3.5.

 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 2 files changed, 2 insertions(+), 6 deletions(-)

diff --cc .travis.yml
index 35c3502e8,aad0c3c3e..21c86ad93
--- a/.travis.yml
+++ b/.travis.yml
@@@ -55,23 -44,9 +55,22 @@@ matrix
compiler: clang
  ## We include a single coverage build with the best options for coverage
  - env: COVERAGE_OPTIONS="--enable-coverage" HARDENING_OPTIONS=""
 +## We run rust on Linux, because it's faster than rust on macOS
 +## We check rust offline
 +- env: RUST_OPTIONS="--enable-rust" TOR_RUST_DEPENDENCIES=true
 +## We check asciidoc with distcheck, to make sure we remove doc products
 +- env: DISTCHECK="yes" ASCIIDOC_OPTIONS="" SKIP_MAKE_CHECK="yes"
 +## We check disable module dirauth
 +- env: MODULES_OPTIONS="--disable-module-dirauth"
 +## We run rust on macOS, because we have seen macOS rust failures before
 +- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
 +  compiler: clang
 +  os: osx
  ## We run chutney on macOS, because macOS Travis has IPv6
- # Disabled due to slow Travis macOS builds, see #32177
- #- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
- #  os: osx
+ - env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
+   os: osx
 +## We clone our stem repo and run `make test-stem`
 +- env: TEST_STEM="yes" SKIP_MAKE_CHECK="yes"
  
## Allow the build to report success (with non-required sub-builds
## continuing to run) if all required sub-builds have succeeded.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.1] Merge branch 'maint-0.2.9' into maint-0.3.5

2019-12-15 Thread teor
commit 1cd20ff848eab6ee7b441c5aab0578ab02a114bc
Merge: 05908d57f 7dd594609
Author: teor 
Date:   Mon Dec 16 08:15:55 2019 +1000

Merge branch 'maint-0.2.9' into maint-0.3.5




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.1] Revert "Travis: Disable all but one macOS build"

2019-12-15 Thread teor
commit 99b5f1b261a3b8535e8e9b8ca8ca23303c2aea2d
Author: teor 
Date:   Thu Nov 28 12:10:10 2019 +1000

Revert "Travis: Disable all but one macOS build"

This reverts commit 511aeba8eeb24a953228e00917f64703059a7673.
---
 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 2 files changed, 2 insertions(+), 6 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 4ea9400b8..aad0c3c3e 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -45,9 +45,8 @@ matrix:
 ## We include a single coverage build with the best options for coverage
 - env: COVERAGE_OPTIONS="--enable-coverage" HARDENING_OPTIONS=""
 ## We run chutney on macOS, because macOS Travis has IPv6
-# Disabled due to slow Travis macOS builds, see #32177
-#- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
-#  os: osx
+- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
+  os: osx
 
   ## Allow the build to report success (with non-required sub-builds
   ## continuing to run) if all required sub-builds have succeeded.
diff --git a/changes/ticket32177 b/changes/ticket32177
deleted file mode 100644
index 6d6816acd..0
--- a/changes/ticket32177
+++ /dev/null
@@ -1,3 +0,0 @@
-  o Testing:
-- Disable all but one Travis CI macOS build, to mitigate slow scheduling
-  of Travis macOS jobs. Closes ticket 32177.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.1] Travis: Disable the macOS Rust job

2019-12-15 Thread teor
commit 6558bb4460f360ee16653d9430ee00e969f3adf7
Author: teor 
Date:   Sun Dec 1 20:25:00 2019 +1000

Travis: Disable the macOS Rust job

This time, we're disabling it because it's the lowest priority job.
(And also slow.)

Part of 32629.
---
 .travis.yml | 9 ++---
 1 file changed, 6 insertions(+), 3 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 21c86ad93..bdcd94f91 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -62,10 +62,13 @@ matrix:
 - env: DISTCHECK="yes" ASCIIDOC_OPTIONS="" SKIP_MAKE_CHECK="yes"
 ## We check disable module dirauth
 - env: MODULES_OPTIONS="--disable-module-dirauth"
+## macOS builds are very slow, and we have a limited number of
+## concurrent macOS jobs. We're not actively developing Rust, so it is
+## the lowest priority.
 ## We run rust on macOS, because we have seen macOS rust failures before
-- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
-  compiler: clang
-  os: osx
+#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
+#  compiler: clang
+#  os: osx
 ## We run chutney on macOS, because macOS Travis has IPv6
 - env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
   os: osx



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.1] Merge remote-tracking branch 'tor-github/pr/1576' into maint-0.3.5

2019-12-15 Thread teor
commit 05908d57f64a4365f6715f19aba51ccd5849e635
Merge: 0c4f0ec97 a277f2894
Author: teor 
Date:   Mon Dec 16 08:14:04 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1576' into maint-0.3.5

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.1] changes: file for 32629

2019-12-15 Thread teor
commit a277f28947900fc2018f634078bf59eae166c75a
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.1] Merge branch 'maint-0.3.5' into maint-0.4.0

2019-12-15 Thread teor
commit 748117298341de8a279f4437b6d557f0d50edb63
Merge: b9504f788 1cd20ff84
Author: teor 
Date:   Mon Dec 16 08:16:04 2019 +1000

Merge branch 'maint-0.3.5' into maint-0.4.0

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.1] Merge branch 'maint-0.4.0' into maint-0.4.1

2019-12-15 Thread teor
commit ffccf6fc55f691e01ccd3e756486415cbc7ffe8a
Merge: 7174a80ed 748117298
Author: teor 
Date:   Mon Dec 16 08:16:12 2019 +1000

Merge branch 'maint-0.4.0' into maint-0.4.1

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.1] Revert "Travis: Disable the Rust macOS build"

2019-12-15 Thread teor
commit 453e092e521626420fb679ad99fade0dd1c9af88
Author: teor 
Date:   Thu Nov 28 12:11:37 2019 +1000

Revert "Travis: Disable the Rust macOS build"

This reverts commit 4c4a0d50ff4fd01862b78e8cbfaabfa9e4d4ae12.
---
 .travis.yml | 7 +++
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 7f0e78587..35c3502e8 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -63,10 +63,9 @@ matrix:
 ## We check disable module dirauth
 - env: MODULES_OPTIONS="--disable-module-dirauth"
 ## We run rust on macOS, because we have seen macOS rust failures before
-# Disabled due to slow Travis macOS builds, see #32177
-#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
-#  compiler: clang
-#  os: osx
+- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
+  compiler: clang
+  os: osx
 ## We run chutney on macOS, because macOS Travis has IPv6
 # Disabled due to slow Travis macOS builds, see #32177
 #- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.0] changes: file for 32629

2019-12-15 Thread teor
commit b84e7715daba5bdcb20fa3f1148d2c518ea5704c
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.0] changes: file for 32629

2019-12-15 Thread teor
commit a277f28947900fc2018f634078bf59eae166c75a
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.0] Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

2019-12-15 Thread teor
commit 7dd59460941c50242e740ff0cbd84b588d66e26e
Merge: b7b467d3a b84e7715d
Author: teor 
Date:   Mon Dec 16 08:13:38 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 6 insertions(+), 6 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.0] Merge remote-tracking branch 'tor-github/pr/1576' into maint-0.3.5

2019-12-15 Thread teor
commit 05908d57f64a4365f6715f19aba51ccd5849e635
Merge: 0c4f0ec97 a277f2894
Author: teor 
Date:   Mon Dec 16 08:14:04 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1576' into maint-0.3.5

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.1] Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

2019-12-15 Thread teor
commit 7dd59460941c50242e740ff0cbd84b588d66e26e
Merge: b7b467d3a b84e7715d
Author: teor 
Date:   Mon Dec 16 08:13:38 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 6 insertions(+), 6 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.1] changes: file for 32629

2019-12-15 Thread teor
commit b84e7715daba5bdcb20fa3f1148d2c518ea5704c
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.0] Merge branch 'maint-0.3.5' into maint-0.4.0

2019-12-15 Thread teor
commit 748117298341de8a279f4437b6d557f0d50edb63
Merge: b9504f788 1cd20ff84
Author: teor 
Date:   Mon Dec 16 08:16:04 2019 +1000

Merge branch 'maint-0.3.5' into maint-0.4.0

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.0] Merge branch 'maint-0.2.9' into maint-0.3.5

2019-12-15 Thread teor
commit 1cd20ff848eab6ee7b441c5aab0578ab02a114bc
Merge: 05908d57f 7dd594609
Author: teor 
Date:   Mon Dec 16 08:15:55 2019 +1000

Merge branch 'maint-0.2.9' into maint-0.3.5




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.3.5] Merge remote-tracking branch 'tor-github/pr/1576' into maint-0.3.5

2019-12-15 Thread teor
commit 05908d57f64a4365f6715f19aba51ccd5849e635
Merge: 0c4f0ec97 a277f2894
Author: teor 
Date:   Mon Dec 16 08:14:04 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1576' into maint-0.3.5

 .travis.yml | 9 +
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 9 insertions(+), 7 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.0] Travis: Disable the macOS Rust job

2019-12-15 Thread teor
commit 6558bb4460f360ee16653d9430ee00e969f3adf7
Author: teor 
Date:   Sun Dec 1 20:25:00 2019 +1000

Travis: Disable the macOS Rust job

This time, we're disabling it because it's the lowest priority job.
(And also slow.)

Part of 32629.
---
 .travis.yml | 9 ++---
 1 file changed, 6 insertions(+), 3 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 21c86ad93..bdcd94f91 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -62,10 +62,13 @@ matrix:
 - env: DISTCHECK="yes" ASCIIDOC_OPTIONS="" SKIP_MAKE_CHECK="yes"
 ## We check disable module dirauth
 - env: MODULES_OPTIONS="--disable-module-dirauth"
+## macOS builds are very slow, and we have a limited number of
+## concurrent macOS jobs. We're not actively developing Rust, so it is
+## the lowest priority.
 ## We run rust on macOS, because we have seen macOS rust failures before
-- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
-  compiler: clang
-  os: osx
+#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
+#  compiler: clang
+#  os: osx
 ## We run chutney on macOS, because macOS Travis has IPv6
 - env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"
   os: osx



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.3.5] Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

2019-12-15 Thread teor
commit 7dd59460941c50242e740ff0cbd84b588d66e26e
Merge: b7b467d3a b84e7715d
Author: teor 
Date:   Mon Dec 16 08:13:38 2019 +1000

Merge remote-tracking branch 'tor-github/pr/1575' into maint-0.2.9

 .travis.yml | 5 ++---
 changes/ticket32177 | 3 ---
 changes/ticket32629 | 4 
 3 files changed, 6 insertions(+), 6 deletions(-)




___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.4.0] Revert "Travis: Disable the Rust macOS build"

2019-12-15 Thread teor
commit 453e092e521626420fb679ad99fade0dd1c9af88
Author: teor 
Date:   Thu Nov 28 12:11:37 2019 +1000

Revert "Travis: Disable the Rust macOS build"

This reverts commit 4c4a0d50ff4fd01862b78e8cbfaabfa9e4d4ae12.
---
 .travis.yml | 7 +++
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 7f0e78587..35c3502e8 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -63,10 +63,9 @@ matrix:
 ## We check disable module dirauth
 - env: MODULES_OPTIONS="--disable-module-dirauth"
 ## We run rust on macOS, because we have seen macOS rust failures before
-# Disabled due to slow Travis macOS builds, see #32177
-#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
-#  compiler: clang
-#  os: osx
+- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
+  compiler: clang
+  os: osx
 ## We run chutney on macOS, because macOS Travis has IPv6
 # Disabled due to slow Travis macOS builds, see #32177
 #- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.3.5] Revert "Travis: Disable the Rust macOS build"

2019-12-15 Thread teor
commit 453e092e521626420fb679ad99fade0dd1c9af88
Author: teor 
Date:   Thu Nov 28 12:11:37 2019 +1000

Revert "Travis: Disable the Rust macOS build"

This reverts commit 4c4a0d50ff4fd01862b78e8cbfaabfa9e4d4ae12.
---
 .travis.yml | 7 +++
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/.travis.yml b/.travis.yml
index 7f0e78587..35c3502e8 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -63,10 +63,9 @@ matrix:
 ## We check disable module dirauth
 - env: MODULES_OPTIONS="--disable-module-dirauth"
 ## We run rust on macOS, because we have seen macOS rust failures before
-# Disabled due to slow Travis macOS builds, see #32177
-#- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
-#  compiler: clang
-#  os: osx
+- env: RUST_OPTIONS="--enable-rust --enable-cargo-online-mode"
+  compiler: clang
+  os: osx
 ## We run chutney on macOS, because macOS Travis has IPv6
 # Disabled due to slow Travis macOS builds, see #32177
 #- env: CHUTNEY="yes" CHUTNEY_ALLOW_FAILURES="2" SKIP_MAKE_CHECK="yes"



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.3.5] Merge branch 'maint-0.2.9' into maint-0.3.5

2019-12-15 Thread teor
commit 1cd20ff848eab6ee7b441c5aab0578ab02a114bc
Merge: 05908d57f 7dd594609
Author: teor 
Date:   Mon Dec 16 08:15:55 2019 +1000

Merge branch 'maint-0.2.9' into maint-0.3.5

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/maint-0.2.9] changes: file for 32629

2019-12-15 Thread teor
commit b84e7715daba5bdcb20fa3f1148d2c518ea5704c
Author: teor 
Date:   Fri Dec 6 10:51:05 2019 +1000

changes: file for 32629
---
 changes/ticket32629 | 4 
 1 file changed, 4 insertions(+)

diff --git a/changes/ticket32629 b/changes/ticket32629
new file mode 100644
index 0..740746c57
--- /dev/null
+++ b/changes/ticket32629
@@ -0,0 +1,4 @@
+  o Testing:
+- Re-enable the Travis CI macOS Chutney build, but allow the job to finish
+  before it finishes, because the Travis macOS jobs are slow.
+  Closes ticket 32629.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


  1   2   >
diff --git a/lib/chutney/TorNet.py b/lib/chutney/TorNet.py
index e9cf8f4..2b91dfb 100644
--- a/lib/chutney/TorNet.py
+++ b/lib/chutney/TorNet.py
@@ -11,15 +11,16 @@ from __future__ import print_function
 from __future__ import with_statement
 
 import cgitb
+import errno
+import importlib
 import os
+import platform
+import re
 import signal
+import shutil
 import subprocess
 import sys
-import re
-import errno
 import time
-import shutil
-import importlib
 
 from chutney.Debug import debug_flag, debug
 
@@ -42,22 +43,55 @@ cgitb.enable(format="plain")
 class MissingBinaryException(Exception):
 pass
 
-def getenv_int(envvar, default):
+def getenv_type(env_var, default, type_, type_name=None):
 """
    Return the value of the environment variable 'envar' as an integer,
or 'default' if no such variable exists.
 
-   Raise ValueError if the environment variable is set, but not to
-   an integer.
+   Raise ValueError using type_name if the environment variable is set,
+   but type_() raises a ValueError on its value. (If type_name is None
+   or empty, the ValueError uses type_'s string representation instead.)
 """
-# TODO: Use this function in more places.
-strval = os.environ.get(envvar)
+strval = os.environ.get(env_var)
 if strval is None:
 return default
 try:
-return int(strval)
+return type_(strval)
+except ValueError:
+if not type_name:
+type_name = str(type_)
+raise ValueError(("Invalid value for environment variable '{}': "
+  "expected {}, but got '{}'")
+ .format(env_var, typename, strval))
+
+def getenv_int(env_var, default):
+"""
+   Return the value of the environment variable 'envar' as an int,
+   or 'default' if no such variable exists.
+
+   Raise ValueError if the environment variable is set, but is not an int.
+"""
+return getenv_type(env_var, default, int, type_name='an int')
+
+def getenv_bool(env_var, default):
+"""
+   Return the value of the environment variable 'envar' as a bool,
+   or 'default' if no such variable exists.
+
+   Unlike bool(), converts 0, "False", and "No" to False.
+
+   Raise ValueError if the environment variable is set, but is not a bool.
+"""
+try:
+# Handle integer values
+return bool(getenv_int(env_var, default))
 except ValueError:
-raise ValueError("Invalid value for 
@@ -42,22 +43,55 @@ cgitb.enable(format="plain")
 """
-   Return the value of the environment variable 'envar' as an integer,
+   Return the value of the environment variable 'envar' as type_,
or 'default' if no such variable exists.
 

[tor-commits] [chutney/master] Merge remote-tracking branch 'tor-github/pr/41'

2019-12-15 Thread teor
commit e748a5f28ec9de1b0a2b90fcbe63e76a87d74496
Merge: f21ca55 f9d27ae
Author: teor 
Date:   Mon Dec 16 08:23:49 2019 +1000

Merge remote-tracking branch 'tor-github/pr/41'

 lib/chutney/Debug.py  | 3 +++
 lib/chutney/Host.py   | 4 
 lib/chutney/Templating.py | 4 +++-
 lib/chutney/TorNet.py | 4 +++-
 lib/chutney/Traffic.py| 3 +++
 lib/chutney/Util.py   | 5 -
 lib/chutney/__init__.py   | 4 
 scripts/chutney_tests/__init__.py | 4 
 scripts/chutney_tests/verify.py   | 6 +-
 9 files changed, 33 insertions(+), 4 deletions(-)
